django_analyses.serializers.output.definitions package — django_analyses 0.0.3 documentation

# django_analyses.serializers.output.definitions package

## Submodules

## django_analyses.serializers.output.definitions.file_output_definition module

class `django_analyses.serializers.output.definitions.file_output_definition.` `FileOutputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.output.definitions.file_output_definition.FileOutputDefinition`

## django_analyses.serializers.output.definitions.output_definition module

class `django_analyses.serializers.output.definitions.output_definition.` `OutputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `django_analyses.serializers.utils.polymorphic.PolymorphicSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.output.definitions.output_definition.OutputDefinition`

  `get_serializer`(output_type: str) → rest_framework.serializers.Serializer

    Return a dict to map class names to their respective serializer classes. To be implemented by all PolymorphicSerializer subclasses.

`django_analyses.serializers.output.definitions.output_definition.` `get_extra_output_definition_serializers`() → dict

## Module contents